#!/usr/bin/env python

##    Ce module permet de chiffrer des chaines de caractères et des fichier.
##    Il permet une grande sécurité, et rapidité pour les
##    conversations instantanées.

__all__ = ["NCrypter"]
from NimingCypher.Niming import NCrypter
